# uassist


[![image](https://img.shields.io/pypi/v/uassist.svg)](https://pypi.python.org/pypi/uassist) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/uassist/badges/version.svg)](https://anaconda.org/conda-forge/uassist)


**UASsist: Assistant for Unmanned Aircraft System photogrammetry for surveying and mapping applications. **


-   Free software: GNU General Public License v3
-   Documentation: https://nathanmckinney.github.io/uassist
    

## Features

-   Reads image metadata and displays information important for UAS surveys
-   Displays photo coordinates on a map embedded in a notebook

![Demo](https://i.imgur.com/5GLSavr.jpg)
## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
